@@ -4,7 +4,10 @@ import tempfile
 from typing import List, Mapping, Optional, Tuple, Dict
 
 from ofrak_type import ArchInfo
-from ofrak_patch_maker.binary_parser.llvm import LLVM_ELF_Parser, LLVM_MACH_O_Parser
+from ofrak_type.architecture import InstructionSet
+from ofrak_type.memory_permissions import MemoryPermissions
+
+from ofrak_patch_maker.binary_parser.llvm import LLVM_ELF_Parser
 from ofrak_patch_maker.toolchain.abstract import Toolchain, RBS_AUTOGEN_WARNING
 from ofrak_patch_maker.toolchain.model import (
     Segment,
@@ -14,12 +17,10 @@ from ofrak_patch_maker.toolchain.model import (
     ToolchainException,
 )
 from ofrak_patch_maker.toolchain.utils import get_file_format
-from ofrak_type.architecture import InstructionSet
-from ofrak_type.memory_permissions import MemoryPermissions
 
 
 class LLVM_12_0_1_Toolchain(Toolchain):
-    binary_file_parsers = [LLVM_ELF_Parser(), LLVM_MACH_O_Parser()]
+    binary_file_parsers = [LLVM_ELF_Parser()]
 
     def __init__(
         self,
@@ -67,7 +68,7 @@ class LLVM_12_0_1_Toolchain(Toolchain):
             llvm12_compiler_optimization_map[self._config.compiler_optimization_level]
         )
 
-        if not self._config.userspace_dynamic_linker:
+        if not self.is_userspace():
             self._compiler_flags.append("-ffreestanding")
 
         if self._config.force_inlines:
@@ -141,7 +142,7 @@ class LLVM_12_0_1_Toolchain(Toolchain):
         return "-T"
 
     def compile(self, c_file: str, header_dirs: List[str], out_dir: str = ".") -> str:
-        if self._config.userspace_dynamic_linker:
+        if self.is_userspace():
             out_file = os.path.join(out_dir, os.path.split(c_file)[-1] + ".o")
             # For now a complete override of the flags; we sidestep the clang front-end
             # in favor of a more userspace-friendly GNU configuration.
@@ -156,7 +157,7 @@ class LLVM_12_0_1_Toolchain(Toolchain):
             return super().compile(c_file, header_dirs, out_dir=out_dir)
 
     def link(self, o_files: List[str], exec_path: str, script=None):
-        if self._config.userspace_dynamic_linker:
+        if self.is_userspace():
             # We will ignore the script and any lld flags in this case
             flags = [
                 f"--dynamic-linker={self._config.userspace_dynamic_linker}",
