@@ -97,7 +97,7 @@ def generate_arm_stubs(
     jump to thumb code, or the opposite). With those stubs, the linker has explicit information
     about the destination mode, so it jumps correctly (exchanging mode or not).
 
-    It is not [PatchMaker's][ofrak_patch_maker.patch_maker.PatchMaker] responsibility to
+    It is not [PatchMaker][ofrak_patch_maker.patch_maker.PatchMaker]'s responsibility to
     programmatically generate source in this way.
 
     Furthermore, this functionality is much more complex than `base_symbols={}` addition implies,
@@ -129,7 +129,9 @@ def generate_arm_stubs(
     return segment_map
 
 
-def _gen_file(
+# Helper function excluded from function coverage results since it runs in a process pool. Tests
+# for generate_arm_stubs test this helper function.
+def _gen_file(  # pragma: no cover
     name: str, address: int, stub_str: str, out_dir: str
 ) -> Mapping[str, Tuple[Segment, Segment]]:
     path = os.path.join(out_dir, name + ".as")
